/// <reference types="react" />
import React from 'react';
import { SvgIconTypeMap, ExtendButtonBase, ButtonTypeMap } from '@mui/material';
import { OverridableComponent } from '@mui/material/OverridableComponent';
import { ThemeOptions } from '@mui/material/styles/createTheme';
import { MaterialReactTableProps, MRT_TableInstance, MRT_Row, MRT_Cell, MRT_ColumnDef } from 'material-react-table';
import { ReportApi, IRequestOptions, IReportListItemResponse } from 'peekdata-datagateway-api-sdk';
import { SvgIconTypeMap as SvgIconTypeMap$1 } from '@mui/material/SvgIcon';
import { ThemeOptions as ThemeOptions$1 } from '@mui/material/styles';

interface Theme extends ThemeOptions {
}
interface ReportsTableProps {
    reportApi: ReportApi;
    userId?: string;
    requestOptions?: IRequestOptions;
    tableProps?: MaterialReactTableProps<IReportListItemResponse>;
    theme?: Theme;
    enableTitleEditing?: boolean;
    EditIcon?: OverridableComponent<SvgIconTypeMap<{}, "svg">> & {
        muiName: string;
    };
    DeleteIcon?: OverridableComponent<SvgIconTypeMap<{}, "svg">> & {
        muiName: string;
    };
    AddButton?: ExtendButtonBase<ButtonTypeMap<{}, "button">>;
    onAddReportClick?: (table: MRT_TableInstance<IReportListItemResponse>) => void;
    onEditReportClick?: (report: IReportListItemResponse, row: MRT_Row<IReportListItemResponse>, table: MRT_TableInstance<IReportListItemResponse>) => void;
    onDeleteReportClick?: (report: IReportListItemResponse, row: MRT_Row<IReportListItemResponse>, table: MRT_TableInstance<IReportListItemResponse>) => void;
}

declare const ReportsTable: React.FC<ReportsTableProps>;

interface TableActionButtonProps {
    tooltipPlacement?: "top" | "right" | "bottom" | "left" | "bottom-end" | "bottom-start" | "left-end" | "left-start" | "right-end" | "right-start" | "top-end" | "top-start";
    showTooltip?: boolean;
    showTooltipArrow?: boolean;
    tooltipText?: string;
    Icon: OverridableComponent<SvgIconTypeMap$1<{}, "svg">> & {
        muiName: string;
    };
    onClick: () => void;
}

declare const TableActionButton: <TData extends Record<string, any>>(props: TableActionButtonProps) => JSX.Element;

interface TableRowRenderProps<TData extends Record<string, any>> {
    cell: MRT_Cell<TData>;
    row: MRT_Row<TData>;
    table: MRT_TableInstance<TData>;
}
interface TableProps<TData extends Record<string, any>> extends MaterialReactTableProps<TData> {
}

declare const defaultReportTableColumns: MRT_ColumnDef<IReportListItemResponse>[];

declare const defaultTableProperties: MaterialReactTableProps<IReportListItemResponse>;

declare const defaultTheme: ThemeOptions$1;

export { ReportsTable, ReportsTableProps, TableActionButton, TableActionButtonProps, TableProps, TableRowRenderProps, Theme, defaultReportTableColumns, defaultTableProperties as defaultReportTableProperties, defaultTheme };
